@@ -1,5 +1,5 @@
 #!/bin/sh
-# @(#) $Id: Exiftimestamps.sh 297 2019-03-02 22:29:03Z leres $ (XSE)
+# @(#) $Id: Exiftimestamps.sh 369 2025-11-07 23:23:49Z leres $ (XSE)
 #
 # Exiftimestamps - set jpg timestamps using exiftags and touch
 #
@@ -12,43 +12,33 @@ usage()
 	exit 1
 }
 
-args=`getopt dnv $*`
-
-if [ $? -ne 0 ]; then
-	usage
-fi
-
-set -- ${args}
-
 dryrun=0
 verbose=0
 debug=0
 
-for a do
-	case "${a}" in
+while getopts dnv opt ; do
+	case "$opt" in
 
-	-d)
+	d)
 		debug=1
-		shift
 		;;
 
-	-n)
+	n)
 		dryrun=1
-		shift
 		;;
 
-	-v)
+	v)
 		verbose=1
-		shift
 		;;
 
-	--)
-		shift
-		break
+	?)
+		usage
 		;;
 	esac
 done
 
+shift $((${OPTIND} - 1))
+
 if [ $# -lt 1 ]; then
 	usage
 fi
