@@ -1,5 +1,5 @@
 /*
- * @(#) $Id: cf.c 358 2025-07-07 00:29:27Z leres $ (XSE)
+ * @(#) $Id: cf.c 361 2025-09-09 18:23:54Z leres $ (XSE)
  *
  * Copyright (c) 1999, 2000, 2001, 2002, 2003, 2004, 2006, 2007, 2008, 2009, 2015, 2017, 2018, 2019, 2020, 2022, 2023, 2025
  *	Craig Leres
@@ -426,7 +426,10 @@ readcf(const char *fn, struct cf *cf, int mustexist)
 		}
 
 		/* Keyword commands */
-		if (strcasecmp(cp2, "dirdetail") == 0) {
+		if (strcasecmp(cp2, "autodaysection") == 0) {
+			cf->c_flags |= C_DAY_SECTION;
+			continue;
+		} else if (strcasecmp(cp2, "dirdetail") == 0) {
 			cf->c_flags &= ~ C_NO_DIRDETAIL;
 			continue;
 		} else if (strcasecmp(cp2, "appdirindexfn") == 0) {
