@@ -1,5 +1,5 @@
 /*
- * @(#) $Id: exif.c 344 2023-10-08 02:12:27Z leres $ (XSE)
+ * @(#) $Id: exif.c 345 2023-10-10 19:56:04Z leres $ (XSE)
  *
  * Copyright (c) 2023
  *	Craig Leres
@@ -16,15 +16,17 @@
  */
 
 #include <ctype.h>
-#include <time.h>
+#include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <time.h>
 
 #include <libexif/exif-data.h>
 #include <libexif/exif-loader.h>
 #include <libexif/exif-ifd.h>
 
+#include "cf.h"
 #include "exif.h"
 
 /* Forwards */
@@ -90,6 +92,7 @@ getexiftime(ExifData *ed)
 
 	snprintf(datetime2, sizeof(datetime2), "%s %s", datetime, offset);
 
+	memset(&tm, 0, sizeof(tm));
 	cp = strptime(datetime2, "%Y:%m:%d %H:%M:%S %z", &tm);
 	if (*cp != '\0')
 		return (0);
@@ -100,10 +103,16 @@ getexiftime(ExifData *ed)
 static time_t
 getexiftime2(ExifData *ed, const char *tz)
 {
-	char *cp, *datetime3, *tzfmt;
+	char *cp, *lasttz, *otz;
+	time_t ts, lastts;
 	struct tm tm;
+	struct cf *cf;
+	struct tzlist *tl;
 	char datetime[32];
 	char datetime2[64];
+	static const char tzname[] = "TZ";
+	const char *offfmt = "%Y:%m:%d %H:%M:%S %z";
+	const char *localfmt = "%Y:%m:%d %H:%M:%S";
 
 	memset(datetime, 0, sizeof(datetime));
 	gettag(ed, EXIF_IFD_EXIF, EXIF_TAG_DATE_TIME_ORIGINAL,
@@ -111,23 +120,80 @@ getexiftime2(ExifData *ed, const char *tz)
 	if (datetime[0] == '\0')
 		return (0);
 
-	if (tz == NULL) {
-		/* Use system default tz */
-		datetime3 = datetime;
-		tzfmt = "";
-		tzfmt = "%Y:%m:%d %H:%M:%S";
-	} else {
-		/* Use specified tz */
+
+	/* Use specified tz */
+	if (tz != NULL) {
 		snprintf(datetime2, sizeof(datetime2), "%s %s", datetime, tz);
-		datetime3 = datetime2;
-		tzfmt = "%Y:%m:%d %H:%M:%S %z";
+		memset(&tm, 0, sizeof(tm));
+		cp = strptime(datetime2, offfmt, &tm);
+		if (*cp != '\0')
+			return (0);
+		return (mktime(&tm));
 	}
 
-	cp = strptime(datetime3, tzfmt, &tm);
-	if (*cp != '\0')
-		return (0);
+	cf = parsecf(configfn);
+	if (cf == NULL || cf->c_tzlist == NULL) {
+		/* Use system default tz */
+		memset(&tm, 0, sizeof(tm));
+		cp = strptime(datetime, localfmt, &tm);
+		if (*cp != '\0')
+			return (0);
+		return (mktime(&tm));
+	}
+#ifdef notdef
+memset(&tm, 0, sizeof(tm));
+cp = strptime(datetime, localfmt, &tm);
+#endif
 
-	return (mktime(&tm));
+	/* Try to leverage webindex configured tz */
+	lasttz = NULL;
+	lastts = 0;
+	otz = NULL;
+
+	/* Save the timezone */
+	otz = getenv(tz);
+	if (otz != NULL) {
+		otz = strdup(otz);
+		if (otz == NULL) {
+			fprintf(stderr, "getexiftime2: strdup: %s\n",
+			    strerror(errno));
+			exit(1);
+		}
+	}
+
+	for (tl = cf->c_tzlist; tl != NULL; tl = tl->t_next) {
+		if (lasttz != NULL && strcmp(lasttz, tl->t_tz) == 0)
+			continue;
+
+		setenv(tzname, tl->t_tz, 1);
+		memset(&tm, 0, sizeof(tm));
+		cp = strptime(datetime, localfmt, &tm);
+		if (*cp != '\0')
+			continue;
+
+		ts = mktime(&tm);
+		if (tm.tm_isdst)
+			ts -= 3600;
+		if (tl->t_start == 0 || ts >= tl->t_start) {
+			lasttz = tl->t_tz;
+			lastts = ts;
+		}
+	}
+
+
+	/* Restore timezone */
+	if (otz != NULL) {
+		setenv(tz, otz, 1);
+		free(otz);
+	} else {
+#ifdef HAVE_UNSETENV
+		unsetenv(tz);
+#else
+		setenv(tz, "", 1);
+#endif
+	}
+
+	return (lastts);
 }
 
 static time_t
@@ -153,6 +219,7 @@ getgstime(ExifData *ed)
 		*cp = '\0';
 
 	(void)snprintf(datetime, sizeof(datetime), "%s %s -0000", date, time);
+	memset(&tm, 0, sizeof(tm));
 	cp = strptime(datetime, "%Y:%m:%d %H:%M:%S %z", &tm);
 	if (cp == NULL || *cp != '\0')
 		return (0);
@@ -170,14 +237,17 @@ exiftime(FILE *f, const char *tz)
 	if (ed == NULL)
 		return (0);
 
+	/* Best case: localtime and tz offset */
 	t = getexiftime(ed);
 	if (t != 0)
 		return (t);
 
+	/* Next best: GPS time and date (with -0000 offset) */
 	t = getgstime(ed);
 	if (t != 0)
 		return (t);
 
+	/* Most difficult: see if we if configured tz(s) help */
 	t = getexiftime2(ed, tz);
 	if (t != 0)
 		return (t);
