@@ -1,7 +1,7 @@
 /*
- * @(#) $Id: gif.c 287 2017-01-21 19:15:36Z leres $ (XSE)
+ * @(#) $Id: gif.c 352 2024-12-28 21:09:42Z leres $ (XSE)
  *
- * Copyright (c) 1999, 2000, 2008, 2009, 2010, 2015, 2017
+ * Copyright (c) 1999, 2000, 2008, 2009, 2010, 2015, 2017, 2024
  *	Craig Leres
  *
  * Redistribution and use in source and binary forms, with or without
@@ -23,11 +23,6 @@
 #include <string.h>
 #include <unistd.h>
 
-#include "gnuc.h"
-#ifdef HAVE_OS_PROTO_H
-#include "os-proto.h"
-#endif
-
 #include "gif.h"
 
 int
