@@ -1,10 +1,11 @@
 #!/bin/sh
-# @(#) $Id: jpegrotate.sh 303 2020-03-08 20:05:17Z leres $ (XSE)
+# @(#) $Id: jpegrotate.sh 369 2025-11-07 23:23:49Z leres $ (XSE)
 #
 # jpegrotate - rotate jpeg images
 #
 
 prog="`basename $0`"
+
 usage()
 {
 	echo "${prog} file ...	# auto-rotate" 1>&2
@@ -27,78 +28,62 @@ automatic=1
 dryrun=0
 force=0
 option=""
-status=0
 override=0
+status=0
 undo=0
 
-args=`getopt FfhlOnruV $*`
+while getopts fhlnruFOV opt ; do
+	case "$opt" in
 
-if [ $? -ne 0 ]; then
-	usage
-fi
-
-set -- ${args}
-
-for a do
-	case "${a}" in
-
-	-l)
-		option="-2"
-		automatic=0
-		shift
-		;;
-
-	-r)
-		option="-9"
-		automatic=0
-		shift
-		;;
-
-	-F)
-		force=1
-		shift
-		;;
-
-	-f)
+	f)
 		option="-1"
 		automatic=0
-		shift
 		;;
 
-	-h)
+	h)
 		option="-F"
 		automatic=0
-		shift
 		;;
 
-	-n)
+	l)
+		option="-2"
+		automatic=0
+		;;
+
+	n)
 		dryrun=1
-		shift
 		;;
 
-	-O)
+	r)
+		option="-9"
+		automatic=0
+		;;
+
+	u)
+		undo=1
+		;;
+
+	F)
+		force=1
+		;;
+
+	O)
 		override=1
-		shift
 		;;
 
-	-V)
+	V)
 		option="-f"
 		automatic=0
-		shift
 		;;
 
-	-u)
-		undo=1
-		shift
-		;;
-
-	--)
-		shift
-		break
+	?)
+		usage
 		;;
 	esac
 done
 
+shift $((${OPTIND} - 1))
+
 if [ -n "${option}" -a ${undo} -ne 0 ]; then
 	usage
 fi
