@@ -1,7 +1,7 @@
 /*
- * @(#) $Id: png.c 287 2017-01-21 19:15:36Z leres $ (XSE)
+ * @(#) $Id: png.c 352 2024-12-28 21:09:42Z leres $ (XSE)
  *
- * Copyright (c) 2005, 2006, 2007, 2008, 2009, 2010, 2015, 2017
+ * Copyright (c) 2005, 2006, 2007, 2008, 2009, 2010, 2015, 2017, 2024
  *	Craig Leres
  *
  * Redistribution and use in source and binary forms, with or without
@@ -27,11 +27,6 @@
 #include "png.h"
 #include "webindex.h"
 
-#include "gnuc.h"
-#ifdef HAVE_OS_PROTO_H
-#include "os-proto.h"
-#endif
-
 int
 parsepng(const char *image, int *wp, int *hp, struct timespec *mtimp)
 {
