@@ -1,7 +1,7 @@
 /*
- * @(#) $Id: timestamps.c 290 2018-04-22 00:27:21Z leres $ (XSE)
+ * @(#) $Id: timestamps.c 342 2023-10-06 23:39:02Z leres $ (XSE)
  *
- * Copyright (c) 1999, 2000, 2001, 2003, 2008, 2009, 2010, 2013, 2015, 2018
+ * Copyright (c) 1999, 2000, 2001, 2003, 2008, 2009, 2010, 2013, 2015, 2018, 2023
  *	Craig Leres
  *
  * Redistribution and use in source and binary forms, with or without
@@ -52,7 +52,7 @@ extern int optind, opterr, optopt;
 int invisible(const char *);
 int main(int, char **);
 int process(const char *, int);
-void usage(void);
+void usage(void) __attribute__((noreturn));
 int mysort(const void *, const void *);
 
 int
