@@ -1,4 +1,4 @@
-/* @(#) $Id: webindex.h 322 2023-01-14 21:42:39Z leres $ (XSE) */
+/* @(#) $Id: webindex.h 345 2023-10-10 19:56:04Z leres $ (XSE) */
 #ifndef webindex_h
 #define webindex_h
 
@@ -50,6 +50,4 @@ extern char prefix[];
 extern const char version[];
 
 const char *naildir(struct cf *);
-int popd(char *, int);
-int pushd(const char *, char **, int *);
 #endif
